{% import "bootstrap/wtf.html" as wtf %}
<title>Chibchas</title>
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta3/dist/css/bootstrap.min.css" rel="stylesheet"
    integrity="sha384-eOJMYsd53ii+scO/bJGFsiCZc+5NDVN2yr8+0RDqr0Ql0h+rP48ckxlpbzKgwra6" crossorigin="anonymous">
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta3/dist/js/bootstrap.bundle.min.js"
    integrity="sha384-JEW9xMcG8R+pH31jmWH6WWP0WintQrMb4s7ZOdauHnUtxwoG2vI5DkLtS3qm9Ekf"
    crossorigin="anonymous"></script>

<!-- <link rel="stylesheet" media="screen" href="static/bootstrap.min.css">
<link rel="stylesheet" href="static/bootstrap-theme.min.css"> -->
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<div class="container">
    <img src="https://avatars.githubusercontent.com/u/44732069?s=200&v=4"/>
    <h2>InstituLAC automation tool</h2>
    <form action="" method="post" role="form">
        <div class="form-group">
                        
            <label for="username">Username:</label>
            <input type="text" class="form-control" id="username" name="username" placeholder="InstituLAC username?" style="width:50%">

            <label for="password">Password:</label>
            <input type="password" class="form-control" id="password" name="password" placeholder="InstituLAC  password." style="width:50%">


        </div><br/>
        <button type="submit" class="btn btn-success">Sign Up</button>
    </form>
    
    
</div>
