<!DOCTYPE html>
<html>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<style>
.loader {
  border: 16px solid #f3f3f3;
  border-radius: 50%;
  border-top: 16px solid #3498db;
  width: 120px;
  height: 120px;
  -webkit-animation: spin 2s linear infinite; /* Safari */
  animation: spin 2s linear infinite;
}

/* Safari */
@-webkit-keyframes spin {
  0% { -webkit-transform: rotate(0deg); }
  100% { -webkit-transform: rotate(360deg); }
}

@keyframes spin {
  0% { transform: rotate(0deg); }
  100% { transform: rotate(360deg); }
}
</style>
</head>
<body>
<center>
<img src="https://raw.githubusercontent.com/colav/colav.github.io/master/img/Logo.png"/>
<h2>Estamos procesando sus datos</h2>

<div class="loader"></div>
<h2>En caso de error por favor volver a autenticarse en la plataforma para continuar, para soporte escribanos a <a href="mailto:grupocolav@udea.edu.co">grupocolav@udea.edu.co</a></h2>
<hr>
<h1>Puedes cerrar la pestaña del navegador si lo deseas, los archivos aparecerán en gdrive. <a href="https://drive.google.com/drive/u/2/folders/0AIfY9XggsOEnUk9PVA" target="_blank">https://drive.google.com/drive/u/2/folders/0AIfY9XggsOEnUk9PVA</a> <h1>
<meta http-equiv="refresh" content="0; URL=/executor" />
</center>

</body>
</html>
